## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----eval = FALSE-------------------------------------------------------------
#  mspms::generate_report(
#    prepared_data = mspms::peaks_prepared_data,
#    design_matrix = mspms::design_matrix,
#    outdir = "../Desktop/mspms_report"
#  )

## -----------------------------------------------------------------------------
library(dplyr)
library(mspms)

### Loading the files ###
lfq_filename <- system.file("extdata/protein-peptides-lfq.csv",
                            package = "mspms")
  
# file "protein-peptides.csv" exported from PEAKS identification
id_filename <- system.file("extdata/protein-peptides-id.csv",
                           package = "mspms")

# Prepare the data for normalyzer analysis
peaks_prepared_data <- prepare_peaks(lfq_filename, id_filename)

## -----------------------------------------------------------------------------

pd_file = system.file("extdata/proteome_discoverer_output.xlsx",
                      package = "mspms")

prepared_proteome_discoverer <- prepare_pd(pd_file)

## -----------------------------------------------------------------------------
all_peptide_sequences <- mspms::calculate_all_cleavages(
  mspms::peptide_library$library_real_sequence,
  n_AA_after_cleavage = 4
  )
head(all_peptide_sequences)

## -----------------------------------------------------------------------------
all_peptide_sequences <- mspms::calculate_all_cleavages(
  mspms::peptide_library$library_real_sequence,
  n_AA_after_cleavage = 5
)
head(all_peptide_sequences)

## -----------------------------------------------------------------------------
design_matrix_fp <- system.file("extdata/design_matrix.csv",
                             package = "mspms")
  
  
design_matrix = readr::read_csv(design_matrix_fp)

head(design_matrix)

## -----------------------------------------------------------------------------
normalyzed_data <- normalyze(peaks_prepared_data, design_matrix)

## -----------------------------------------------------------------------------
outliers <- handle_outliers(normalyzed_data, design_matrix)

## -----------------------------------------------------------------------------
imputed <- mspms::impute(outliers)

## -----------------------------------------------------------------------------
joined_with_library <- mspms::join_with_library(imputed)

## -----------------------------------------------------------------------------
cleavage_added_data <- mspms::add_cleavages(joined_with_library, n_residues = 4)

head(cleavage_added_data)

## -----------------------------------------------------------------------------
prepared_for_stats <- mspms::prepare_for_stats(cleavage_added_data,
                                               design_matrix)

## -----------------------------------------------------------------------------
polished_data <- mspms::polish(cleavage_added_data)

## -----------------------------------------------------------------------------
mspms_data <- mspms::mspms(peaks_prepared_data, design_matrix)

## -----------------------------------------------------------------------------

mspms_data = mspms::mspms_data
# Perform T test
t_test_stats <- mspms::mspms_t_tests(mspms_data)

## -----------------------------------------------------------------------------
# calculate log2fc
log2fc <- mspms::mspms_log2fc(mspms_data)

head(log2fc)

## -----------------------------------------------------------------------------
log2fc_t_test <- mspms::log2fc_t_test(mspms_data)

head(log2fc_t_test)

## -----------------------------------------------------------------------------
condition_t = mspms::log2fct_condition(mspms_data,
                                       ref_condition = "DMSO",
                                       comparison_condition = "MZB",
                                       at_time = 60)


head(condition_t)


## -----------------------------------------------------------------------------
time_t = mspms::log2fct_time(mspms_data,
                             within_condition = "DMSO",
                             ref_time = 0,
                             comparison_time = 60)

head(time_t)

## -----------------------------------------------------------------------------
# Doing ANOVA
anova_stats <- mspms::mspms_anova(mspms_data)

head(anova_stats)

## -----------------------------------------------------------------------------
volcano_plot <- mspms::plot_volcano(log2fc_t_test)

volcano_plot

## -----------------------------------------------------------------------------
cleavage_seqs <- time_t %>%
  dplyr::filter(log2fc > 3, p.adj <= 0.05) %>%
  dplyr::pull(cleavage_seq)

background_universe <- mspms::all_possible_8mers_from_228_library


mspms::plot_icelogo(cleavage_seqs, background_universe)

## -----------------------------------------------------------------------------
mspms::plot_icelogo(cleavage_seqs, background_universe, type = "fold_change")

## -----------------------------------------------------------------------------
plot_all_icelogos(mspms_data)

plot_all_icelogos(mspms_data, type = "fold_change")

## -----------------------------------------------------------------------------

# Getting data for Icelog 
cleavage_seqs <- time_t %>%
  dplyr::filter(log2fc > 3, p.adj <= 0.05) %>%
  dplyr::pull(cleavage_seq)

background_universe <- mspms::all_possible_8mers_from_228_library

# Plotting icelogo
mspms::plot_icelogo(cleavage_seqs, background_universe)

# corresponding icelogo data to the plot
icelogo_matrix = mspms::prepare_icelogo_data(cleavage_seqs, background_universe)

# Extracting regular expressions
RE_pos = mspms::extract_re(icelogo_matrix)

RE_pos

## -----------------------------------------------------------------------------
RE_neg = mspms::extract_re(icelogo_matrix,type = "negative")

RE_neg

## -----------------------------------------------------------------------------
pos_enriched = mspms_data %>% 
  dplyr::filter(grepl(RE_pos, cleavage_seq))

## -----------------------------------------------------------------------------
# Extracting regular expressions 
RE_pos = mspms::extract_re(icelogo_matrix,threshold = 10)

RE_pos

# Filtering data for peptides that have cleavage sequences matching regular 
# expressions
f = mspms_data %>% 
  dplyr::filter(grepl(RE_pos, cleavage_seq))

#visualizing these peptides that match over time.
plot_time_course(f)

## -----------------------------------------------------------------------------
mspms::plot_pca(mspms_data)

## ----eval=FALSE---------------------------------------------------------------
#  mspms::plot_heatmap(mspms_data)

## -----------------------------------------------------------------------------

top10sig <- anova_stats %>%
  dplyr::arrange(p.adj) %>%
  dplyr::pull(Peptide) %>%
  head(10)


p1 <- mspms_data %>%
  dplyr::filter(Peptide %in% top10sig) %>%
  mspms::plot_time_course()

p1

## -----------------------------------------------------------------------------
# Performing T tests
t_tests = log2fc_t_test(mspms_data) %>% 
  dplyr::filter(p.adj < 0.05,
                log2fc > 3)

count = mspms::count_cleavages_per_pos(t_tests)

p1 = mspms:::plot_cleavages_per_pos(count)

p1

## -----------------------------------------------------------------------------
sessionInfo()

